==> zio-aws-appconfig_3-5.17.130.2-sources.jar: zio/aws/appconfig/model/StopDeploymentRequest.scala <==
package zio.aws.appconfig.model
import zio.aws.appconfig.model.primitives.Id
import java.lang.Integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class StopDeploymentRequest(
    applicationId: Id,
    environmentId: Id,
    deploymentNumber: zio.aws.appconfig.model.primitives.Integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest = {
    import StopDeploymentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
      .builder()
      .applicationId(Id.unwrap(applicationId): java.lang.String)
      .environmentId(Id.unwrap(environmentId): java.lang.String)
      .deploymentNumber(
        zio.aws.appconfig.model.primitives.Integer
          .unwrap(deploymentNumber): Integer
      )
      .build()
  }
  def asReadOnly: zio.aws.appconfig.model.StopDeploymentRequest.ReadOnly =
    zio.aws.appconfig.model.StopDeploymentRequest.wrap(buildAwsValue())
}
object StopDeploymentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appconfig.model.StopDeploymentRequest =
      zio.aws.appconfig.model
        .StopDeploymentRequest(applicationId, environmentId, deploymentNumber)
    def applicationId: Id
    def environmentId: Id
    def deploymentNumber: zio.aws.appconfig.model.primitives.Integer
    def getApplicationId: ZIO[Any, Nothing, Id] = ZIO.succeed(applicationId)
    def getEnvironmentId: ZIO[Any, Nothing, Id] = ZIO.succeed(environmentId)
    def getDeploymentNumber
        : ZIO[Any, Nothing, zio.aws.appconfig.model.primitives.Integer] =
      ZIO.succeed(deploymentNumber)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
  ) extends zio.aws.appconfig.model.StopDeploymentRequest.ReadOnly {
    override val applicationId: Id =
      zio.aws.appconfig.model.primitives.Id(impl.applicationId())
    override val environmentId: Id =
      zio.aws.appconfig.model.primitives.Id(impl.environmentId())
    override val deploymentNumber: zio.aws.appconfig.model.primitives.Integer =
      zio.aws.appconfig.model.primitives.Integer(impl.deploymentNumber())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
  ): zio.aws.appconfig.model.StopDeploymentRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appconfig_3-5.19.33.2-sources.jar: zio/aws/appconfig/model/StopDeploymentRequest.scala <==
package zio.aws.appconfig.model
import zio.aws.appconfig.model.primitives.Id
import java.lang.Integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class StopDeploymentRequest(
    applicationId: Id,
    environmentId: Id,
    deploymentNumber: zio.aws.appconfig.model.primitives.Integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest = {
    import StopDeploymentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
      .builder()
      .applicationId(Id.unwrap(applicationId): java.lang.String)
      .environmentId(Id.unwrap(environmentId): java.lang.String)
      .deploymentNumber(deploymentNumber: Integer)
      .build()
  }
  def asReadOnly: zio.aws.appconfig.model.StopDeploymentRequest.ReadOnly =
    zio.aws.appconfig.model.StopDeploymentRequest.wrap(buildAwsValue())
}
object StopDeploymentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appconfig.model.StopDeploymentRequest =
      zio.aws.appconfig.model
        .StopDeploymentRequest(applicationId, environmentId, deploymentNumber)
    def applicationId: Id
    def environmentId: Id
    def deploymentNumber: zio.aws.appconfig.model.primitives.Integer
    def getApplicationId: ZIO[Any, Nothing, Id] = ZIO.succeed(applicationId)
    def getEnvironmentId: ZIO[Any, Nothing, Id] = ZIO.succeed(environmentId)
    def getDeploymentNumber
        : ZIO[Any, Nothing, zio.aws.appconfig.model.primitives.Integer] =
      ZIO.succeed(deploymentNumber)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
  ) extends zio.aws.appconfig.model.StopDeploymentRequest.ReadOnly {
    override val applicationId: Id =
      zio.aws.appconfig.model.primitives.Id(impl.applicationId())
    override val environmentId: Id =
      zio.aws.appconfig.model.primitives.Id(impl.environmentId())
    override val deploymentNumber: zio.aws.appconfig.model.primitives.Integer =
      impl.deploymentNumber(): zio.aws.appconfig.model.primitives.Integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.appconfig.model.StopDeploymentRequest
  ): zio.aws.appconfig.model.StopDeploymentRequest.ReadOnly = new Wrapper(impl)
}
